@@ -7,7 +7,7 @@
 #
 
 package CPANPLUS::Dist::Fedora;
-$CPANPLUS::Dist::Fedora::VERSION = '0.4.2';
+$CPANPLUS::Dist::Fedora::VERSION = '0.4.3';
 use strict;
 use warnings;
 
@@ -97,8 +97,8 @@ make test
 [%- IF 0 -%]
 %defattr(-,root,root,-)[% "\n" %]
 [%- END -%]
-[%- IF licensefiles %]%license [% licensefiles _ "\n" %][%- END -%]
-%doc [% docfiles %]
+[%- IF licensefiles %][% "\n" %]%license [% licensefiles _ "\n" %][%- END -%]
+[% "\n" %]%doc [% docfiles %]
 [% IF (status.is_noarch) -%]
 %{perl_vendorlib}/*
 [% ELSE -%]
@@ -175,7 +175,7 @@ sub init
     $status->mk_accessors(
         qw[ distname distvers extra_files rpmname rpmpath rpmvers rpmdir
             srpmpath specpath is_noarch license summary description
-            ]
+        ]
     );
 
     # This is done to initialise it.
@@ -708,7 +708,7 @@ CPANPLUS::Dist::Fedora - a cpanplus backend to build Fedora/RedHat rpms
 
 =head1 VERSION
 
-version 0.4.2
+version 0.4.3
 
 =head1 SYNOPSIS
 
